import { addTransactionSignature } from './Transaction.mjs';

const generateSigner = context => createSignerFromKeypair(context, context.eddsa.generateKeypair());
const createSignerFromKeypair = (context, keypair) => ({
  publicKey: keypair.publicKey,
  secretKey: keypair.secretKey,
  async signMessage(message) {
    return context.eddsa.sign(message, keypair);
  },
  async signTransaction(transaction) {
    const message = transaction.serializedMessage;
    const signature = context.eddsa.sign(message, keypair);
    return addTransactionSignature(transaction, signature, keypair.publicKey);
  },
  async signAllTransactions(transactions) {
    return Promise.all(transactions.map(transaction => this.signTransaction(transaction)));
  }
});
const isKeypairSigner = signer => signer.secretKey !== undefined;

export { createSignerFromKeypair, generateSigner, isKeypairSigner };
//# sourceMappingURL=Keypair.mjs.map
